rmdawn package — Rmdawn 0.0.1 documentation

# rmdawn package

## Submodules

## rmdawn.extract module

`rmdawn.extract.` `extract_after`(source: str, start: str) → str

  Extract all of the characters after `start`.

  Parameters

    - source – The input string from which to extract a substring.

    - start – The substring that marks the extraction starting place.

    - return – A substring that is extracted from `source`.

  Note

    The `start` string is not include in the result.

`rmdawn.extract.` `extract_before`(source: str, end: str) → str

  Extract all of the characters before start.

  Parameters

    - source – The input string from which to extract a substring.

    - end – The substring that marks the place where extraction will end.

    - return – A substring that is extracted from `source`.

  Note

    The `end` string is not include in the result.

`rmdawn.extract.` `extract_between`(source: str, start: str, end: str) → str

  Extract all of the characters between start and end.

  Parameters

    - source – The input string from which to extract a substring.

    - start – The substring that marks the extraction starting place.

    - end – The substring that marks the place where extraction will end.

    - return – A substring that is extracted from `source`.

  Note

    The `start` and `end` strings are not include in the result.

## rmdawn.rmdawn module

`rmdawn.rmdawn.` `rmdawn`(filenames: List[str]) → str

  Create an R markdown file from YAML, markdown, and code files.

  Parameters

    filenames – A list of YAML, markdown, and code file names.

## rmdawn.rmdusk module

`rmdawn.rmdusk.` `rmdusk`(filename: str) → None

  Extract YAML, code, and markdown files from an R markdown file.

  Parameters

    filename – The name of the input R markdown file.

## Module contents

Rmdawn: a Python package for (de)constructing R markdown files.